@@ -1,6 +1,7 @@
 ;;; mime-edit.el --- Simple MIME Composer for GNU Emacs
 
-;; Copyright (C) 1993,94,95,96,97,98,99,2000 Free Software Foundation, Inc.
+;; Copyright (C) 1993,94,95,96,97,98,99,2000,01,02,03
+;;   Free Software Foundation, Inc.
 
 ;; Author: UMEDA Masanobu <umerin@mse.kyutech.ac.jp>
 ;;	MORIOKA Tomohiko <tomo@kanji.zinbun.kyoto-u.ac.jp>
@@ -235,6 +236,9 @@ To insert a signature file automatically, call the function
     ("application"
      ("octet-stream" ("type" "" "tar" "shar"))
      ("postscript")
+     ("pdf")
+     ("msword")
+     ("vnd.ms-excel")
      ("vnd.ms-powerpoint")
      ("x-kiss" ("x-cnf")))
     ("image"
@@ -320,6 +324,11 @@ To insert a signature file automatically, call the function
      "base64"
      "attachment" (("filename" . file))
      )
+    ("\\.xls$"				; MS Excel
+     "application" "vnd.ms-excel" nil
+     "base64"
+     "attachment" (("filename" . file))
+     )
     ("\\.ppt$"				; MS Power Point
      "application" "vnd.ms-powerpoint" nil
      "base64"
@@ -333,7 +342,12 @@ To insert a signature file automatically, call the function
      )
     ("\\.ps$"
      "application" "postscript"	nil
-     "quoted-printable"
+     "base64"
+     "attachment"	(("filename" . file))
+     )
+    ("\\.pdf$"
+     "application" "pdf"	nil
+     "base64"
      "attachment"	(("filename" . file))
      )
 
@@ -497,6 +511,8 @@ If encoding is nil, it is determined from its contents."
     (iso-8859-7		8 "quoted-printable")
     (iso-8859-8		8 "quoted-printable")
     (iso-8859-9		8 "quoted-printable")
+    (iso-8859-14	8 "quoted-printable")
+    (iso-8859-15	8 "quoted-printable")
     (iso-2022-jp	7 "base64")
     (iso-2022-jp-3	7 "base64")
     (iso-2022-kr	7 "base64")
@@ -650,7 +666,10 @@ If it is not specified for a major-mode,
 	  (if (fboundp 'apel-version)
 	      (concat (apel-version) " "))
 	  (if (featurep 'xemacs)
-	      (concat (cond ((featurep 'utf-2000)
+	      (concat (cond ((and (featurep 'chise)
+				  (boundp 'xemacs-chise-version))
+			     (concat "CHISE-MULE/" xemacs-chise-version))
+			    ((featurep 'utf-2000)
 			     (concat "UTF-2000-MULE/" utf-2000-version))
 			    ((featurep 'mule) "MULE"))
 		      " XEmacs"
@@ -719,7 +738,7 @@ Tspecials means any character that matches with it in header must be quoted.")
   (concat "MIME-Version:"
 	  (mime-encode-field-body
 	   (concat " 1.0 (split by " mime-edit-version ")\n")
-	   "MIME-Version:"))
+	   "MIME-Version"))
   "MIME version field for message/partial.")
 
 
@@ -1057,6 +1076,7 @@ User customizable variables (not documented all of them):
 		     paragraph-separate))
     (run-hooks 'mime-edit-mode-hook)
     (message
+     "%s"
      (substitute-command-keys
       "Type \\[mime-edit-exit] to exit MIME mode, and type \\[mime-edit-help] to get help."))
     ))
@@ -2295,7 +2315,13 @@ Content-Description: S/MIME Encrypted Message][base64]]\n")
 		    (narrow-to-region beg (mime-edit-content-end))
 		    (goto-char beg)
 		    (while (re-search-forward "\\(\\=\\|[^\r]\\)\n" nil t)
-		      (replace-match "\\1\r\n"))))
+		      ;; In a certain period, `replace-match' with "\\N"
+		      ;; converted 8-bit characters into multibyte string,
+		      ;; but it has been fixed at 2004-01-15.
+		      ;;(replace-match "\\1\r\n"))))
+		      (backward-char 1)
+		      (insert "\r")
+		      (forward-char 1))))
 	      (goto-char beg)
 	      (mime-encode-region beg (mime-edit-content-end)
 				  (or encoding "7bit"))
@@ -2605,11 +2631,7 @@ Content-Type: message/partial; id=%s; number=%d; total=%d\n%s\n"
 	    (or (cdr (assq major-mode mime-edit-message-max-lines-alist))
 		mime-edit-message-default-max-lines))
       )
-  (let* ((mime-edit-draft-file-name
-	  (or (buffer-file-name)
-	      (make-temp-name
-	       (expand-file-name "mime-draft" temporary-file-directory))))
-	 (separator mail-header-separator)
+  (let* ((separator mail-header-separator)
 	 (id (concat "\""
 		     (replace-space-with-underline (current-time-string))
 		     "@" (system-name) "\"")))
