@@ -59,9 +59,6 @@ Bourne shell or its equivalent \(not tcsh) is needed for \"2>\"."
 (defvar pgg-pgp-user-id nil
   "PGP ID of your default identity.")
 
-(defvar pgg-pgp-messages-coding-system pgg-messages-coding-system
-  "Coding system used when reading from a PGP external process.")
-
 (defvar pgg-scheme-pgp-instance nil)
 
 ;;;###autoload
@@ -71,9 +68,7 @@ Bourne shell or its equivalent \(not tcsh) is needed for \"2>\"."
 	    (luna-make-entity 'pgg-scheme-pgp))))
 
 (defun pgg-pgp-process-region (start end passphrase program args)
-  (let* ((errors-file-name
-	  (concat temporary-file-directory
-		  (make-temp-name "pgg-errors")))
+  (let* ((errors-file-name (make-temp-file "pgg-errors"))
 	 (args
 	  (append args
 		  pgg-pgp-extra-args
@@ -93,8 +88,7 @@ Bourne shell or its equivalent \(not tcsh) is needed for \"2>\"."
     (unwind-protect
 	(progn
 	  (setq process
-		(apply #'binary-to-text-funcall
-		       pgg-pgp-messages-coding-system
+		(apply #'binary-funcall
 		       #'start-process-shell-command "*PGP*" output-buffer
 		       program args))
 	  (set-process-sentinel process #'ignore)
@@ -177,10 +171,11 @@ Bourne shell or its equivalent \(not tcsh) is needed for \"2>\"."
 	   (format "PGP passphrase for %s: " pgg-pgp-user-id)
 	   (pgg-scheme-lookup-key scheme pgg-pgp-user-id 'sign)))
 	 (args
-	  (list (if clearsign "-fast" "-fbast")
+	  (list (if clearsign "-fast" "-fbas")
 		"+verbose=1" "+language=us" "+batchmode"
 		"-u" pgg-pgp-user-id)))
-    (pgg-pgp-process-region start end passphrase pgg-pgp-program args)
+    (pgg-as-lbt start end 'CRLF
+      (pgg-pgp-process-region start end passphrase pgg-pgp-program args))
     (pgg-process-when-success
       (goto-char (point-min))
       (when (re-search-forward "^-+BEGIN PGP" nil t);XXX
@@ -196,10 +191,9 @@ Bourne shell or its equivalent \(not tcsh) is needed for \"2>\"."
 
 (luna-define-method pgg-scheme-verify-region ((scheme pgg-scheme-pgp)
 					      start end &optional signature)
-  (let* ((basename (expand-file-name "pgg" temporary-file-directory))
-	 (orig-file (make-temp-name basename))
-	 (args '("+verbose=1" "+batchmode" "+language=us"))
-	 (orig-mode (default-file-modes)))
+  (let ((orig-file (make-temp-file "pgg"))
+	(args '("+verbose=1" "+batchmode" "+language=us"))
+	(orig-mode (default-file-modes)))
     (unwind-protect
 	(progn
 	  (set-default-file-modes 448)
@@ -234,8 +228,7 @@ Bourne shell or its equivalent \(not tcsh) is needed for \"2>\"."
 (luna-define-method pgg-scheme-snarf-keys-region ((scheme pgg-scheme-pgp)
 						  start end)
   (let* ((pgg-pgp-user-id (or pgg-pgp-user-id pgg-default-user-id))
-	 (basename (expand-file-name "pgg" temporary-file-directory))
-	 (key-file (make-temp-name basename))
+	 (key-file (make-temp-file "pgg"))
 	 (args
 	  (list "+verbose=1" "+batchmode" "+language=us" "-kaf"
 		key-file)))
